<?php
/**
 * Copyright © 2020 Pinpoint Designs LTD. All rights reserved.
 *
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 */

namespace Pinpoint\DisableAddtocart\Plugin;

use Magento\Catalog\Model\Product;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\ScopeInterface;

/**
 * HideAddToCart Plugin
 */
class HideAddToCart
{
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * HideAddToCart constructor.
     *
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        ScopeConfigInterface $scopeConfig
    ) {
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * Override isSalable to check the attribute sets to disable the add to cart button for.
     *
     * @param Product $product The product instance.
     * @param bool $result The original result of the isSalable method.
     * @return bool The modified result indicating whether the product is salable.
     */
    public function afterIsSalable(Product $product, $result): bool
    {
        // Define the store scope
        $storeScope = ScopeInterface::SCOPE_STORE;

        // Get the attribute sets to disable the add to cart button for from the configuration
        $disableForAttributeSets = $this->scopeConfig->getValue(
            'disable_addtocart_for_attribute_set/general/attribute_sets',
            $storeScope
        );

        // Check if the configuration is not null
        if ($disableForAttributeSets !== null) {
            // Get the product's attribute set ID
            $productAttributeSet = $product->getAttributeSetId();

            // Check if the product's attribute set ID is in the list of disabled sets
            $attributeKey = in_array($productAttributeSet, explode(",", $disableForAttributeSets));

            // If the product's attribute set is in the list, return false to indicate it's not salable
            if ($attributeKey !== false) {
                return false;
            }
        }

        // Return the original result if no disabling condition is met
        return $result;
    }
}
